# Generated by Django 5.1.3 on 2024-12-20 14:37

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SmsConfirm',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('code', models.IntegerField()),
                ('try_count', models.IntegerField(default=0)),
                ('resend_count', models.IntegerField(default=0)),
                ('phone', models.CharField(max_length=20)),
                ('expire_time', models.DateTimeField(blank=True, null=True)),
                ('unlock_time', models.DateTimeField(blank=True, null=True)),
                ('resend_unlock_time', models.DateTimeField(blank=True, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]